@@ -68,6 +68,7 @@ mapi_item_add_recipient (const char *recipients, OlMailRecipientType type, GSLis
 {
 	ExchangeMAPIRecipient *recipient;
 	uint32_t val = 0;
+	uint8_t bVal;
 	const char *str = NULL;
 
 	if (!recipients)
@@ -79,8 +80,8 @@ mapi_item_add_recipient (const char *recipients, OlMailRecipientType type, GSLis
 
 	/* this memory should be freed somewhere, perhaps in the existing
 	 * exchange_mapi_util_free_recipient_list() */
-	recipient->in.req_lpProps = g_new0 (struct SPropValue, 2);
 	recipient->in.req_cValues = 2;
+	recipient->in.req_lpProps = g_new0 (struct SPropValue, recipient->in.req_cValues + 1);
 
 	set_SPropValue_proptag (&(recipient->in.req_lpProps[0]), PR_RECIPIENT_TYPE, (const void *) &type);
 
@@ -88,8 +89,8 @@ mapi_item_add_recipient (const char *recipients, OlMailRecipientType type, GSLis
 	set_SPropValue_proptag (&(recipient->in.req_lpProps[1]), PR_SEND_INTERNET_ENCODING, (const void *)&val);
 
 	/* External recipient properties - set them only when the recipient is unresolved */
-	recipient->in.ext_lpProps = g_new0 (struct SPropValue, 7);
-	recipient->in.ext_cValues = 7;
+	recipient->in.ext_cValues = 8;
+	recipient->in.ext_lpProps = g_new0 (struct SPropValue, recipient->in.ext_cValues + 1);
 
 	val = DT_MAILUSER;
 	set_SPropValue_proptag (&(recipient->in.ext_lpProps[0]), PR_DISPLAY_TYPE, (const void *)&val);
@@ -104,25 +105,28 @@ mapi_item_add_recipient (const char *recipients, OlMailRecipientType type, GSLis
 	set_SPropValue_proptag (&(recipient->in.ext_lpProps[5]), PR_DISPLAY_NAME, (const void *)(str));
 	set_SPropValue_proptag (&(recipient->in.ext_lpProps[6]), PR_7BIT_DISPLAY_NAME, (const void *)(str));
 
+	bVal = FALSE;
+	set_SPropValue_proptag (&(recipient->in.ext_lpProps[7]), PR_SEND_RICH_INFO, &bVal);
+
 	*recipient_list = g_slist_append (*recipient_list, recipient);
 }
 
 static void
 mapi_item_set_from(MapiItem *item, const char *from)
 {
-	if (item->header.from) { 
-		free(item->header.from);
-	}
-	item->header.from = strdup(from);
+	if (item->header.from)
+		g_free (item->header.from);
+
+	item->header.from = g_strdup (from);
 }
 
 static void
 mapi_item_set_subject(MapiItem *item, const char *subject)
 {
 	if (item->header.subject)
-		free(item->header.subject);
+		g_free (item->header.subject);
 
-	item->header.subject = g_strdup(subject);
+	item->header.subject = g_strdup (subject);
 }
 
 #define MAX_READ_SIZE 0x1000
@@ -204,7 +208,7 @@ mapi_item_add_attach (MapiItem *item, CamelMimePart *part, CamelStream *content_
 	
 	item_attach = g_new0 (ExchangeMAPIAttachment, 1);
 
-	item_attach->lpProps = g_new0 (struct SPropValue, 6);
+	item_attach->lpProps = g_new0 (struct SPropValue, 6 + 1);
 
 	flag = ATTACH_BY_VALUE; 
 	set_SPropValue_proptag(&(item_attach->lpProps[i++]), PR_ATTACH_METHOD, (const void *) (&flag));
@@ -316,8 +320,7 @@ mapi_do_multipart (CamelMultipart *mp, MapiItem *item, gboolean *is_first)
 
 
 MapiItem *
-camel_mapi_utils_mime_to_item (CamelMimeMessage *message, CamelAddress *from, CamelAddress *recipients,
-			       CamelException *ex)
+camel_mapi_utils_mime_to_item (CamelMimeMessage *message, CamelAddress *from, CamelException *ex)
 {
 	CamelDataWrapper *dw = NULL;
 	CamelContentType *type;
@@ -335,26 +338,31 @@ camel_mapi_utils_mime_to_item (CamelMimeMessage *message, CamelAddress *from, Ca
 
 	/* headers */
 
-	if (!camel_internet_address_get((const CamelInternetAddress *)from, 0, &namep, &addressp)) {
-		printf("index\n");
-		return (FALSE);
+	if (from) {
+		if (!camel_internet_address_get ((const CamelInternetAddress *)from, 0, &namep, &addressp)) {
+			g_warning ("%s: Invalid 'from' passed in", G_STRFUNC);
+			g_free (item);
+			return NULL;
+		}
+	} else {
+		/* though invalid, then possible, to pass in a message without any 'from' */
+		namep = NULL;
 	}
 
-	/** WARNING: double check **/
 	mapi_item_set_from (item, namep);
 
 	to = camel_mime_message_get_recipients(message, CAMEL_RECIPIENT_TYPE_TO);
-	for (i = 0; camel_internet_address_get(to, i, &namep, &addressp); i++){
+	for (i = 0; to && camel_internet_address_get (to, i, &namep, &addressp); i++){
 		mapi_item_add_recipient (addressp, olTo, &recipient_list);
 	}
 
 	cc = camel_mime_message_get_recipients(message, CAMEL_RECIPIENT_TYPE_CC);
-	for (i = 0; camel_internet_address_get(cc, i, &namep, &addressp); i++) {
+	for (i = 0; cc && camel_internet_address_get (cc, i, &namep, &addressp); i++) {
 		mapi_item_add_recipient (addressp, olCC, &recipient_list);
 	}
 
 	bcc = camel_mime_message_get_recipients(message, CAMEL_RECIPIENT_TYPE_BCC);
-	for (i = 0; camel_internet_address_get(bcc, i, &namep, &addressp); i++) {
+	for (i = 0; bcc && camel_internet_address_get (bcc, i, &namep, &addressp); i++) {
 		mapi_item_add_recipient (addressp, olBCC, &recipient_list);
 	}
 	
@@ -404,7 +412,7 @@ camel_mapi_utils_create_item_build_props (struct SPropValue **value, struct SPro
 	uint32_t *cpid = g_new0 (uint32_t, 1);
 	int i=0;
 
-	props = g_new0 (struct SPropValue, 11);
+	props = g_new0 (struct SPropValue, 11 + 1);
 
 	*cpid = 65001; /* UTF8 */
 	set_SPropValue_proptag(&props[i++], PR_INTERNET_CPID, cpid);
